
#ifndef __MIME_ICONS_H__
# define __MIME_ICONS_H__

#define ICON_get_local_xml_file(x) \
    (gchar *)(rfm_void(RFM_MODULE_DIR, "icons", "mime_icon_get_local_xml_file"))
# define ICON_get_global_xml_file(x) \
    (gchar *)(rfm_void(RFM_MODULE_DIR, "icons", "mime_icon_get_global_xml_file"))
# define ICON_get_filename_from_id(x) \
    (gchar *) (rfm_natural(RFM_MODULE_DIR, "icons", (void *)(x), "mime_icon_get_filename_from_id"))
#endif
